pub enum KeyType {
Curve25519,
EcBp256,
EcBp384,
EcBp512,
EcK256,
EcP224,
EcP256,
EcP384,
EcP521,
Generic,
Rsa,
}Expand description
The algorithm type of a key
Variants
Curve25519
A Montgomery curve key over a prime field for the prime number 2^255-19
EcBp256
An elliptic (Brainpool) curve key over a prime field for a prime of size 256 bit
EcBp384
An elliptic (Brainpool) curve key over a prime field for a prime of size 384 bit
EcBp512
An elliptic (Brainpool) curve key over a prime field for a prime of size 512 bit
EcK256
An elliptic (Koblitz) curve key over a prime field for a prime of size 256 bit
EcP224
An elliptic-curve key over a prime field for a prime of size 224 bit
EcP256
An elliptic-curve key over a prime field for a prime of size 256 bit
EcP384
An elliptic-curve key over a prime field for a prime of size 384 bit
EcP521
An elliptic-curve key over a prime field for a prime of size 521 bit
Generic
A generic key used for block ciphers
Rsa
An RSA key