pub enum Error {
Show 19 variants
ApplyPermissions {
path: PathBuf,
mode: u32,
source: Error,
},
Chown {
path: PathBuf,
user: String,
source: Error,
},
CommandAttachToStdin {
command: String,
},
CommandBackground {
command: String,
source: Error,
},
CommandExec {
command: String,
source: Error,
},
CommandNonZero {
command: String,
exit_status: ExitStatus,
stderr: String,
},
CommandWriteToStdin {
command: String,
source: Error,
},
IoPath {
path: PathBuf,
context: &'static str,
source: Error,
},
NotRunningAsRoot {
context: String,
},
RunningAsRoot {
target_user: String,
context: String,
},
SecretsDirCreate {
path: PathBuf,
system_user: String,
source: Error,
},
SecretsFileCreate {
path: PathBuf,
system_user: String,
source: Error,
},
SecretsFileMetadata {
path: PathBuf,
source: Error,
},
SecretsFileMissing {
path: PathBuf,
},
SecretsFileNotAFile {
path: PathBuf,
},
SecretsFilePermissions {
path: PathBuf,
mode: u32,
},
SecretsFileRead {
path: PathBuf,
source: Error,
},
SecretsFileWrite {
path: PathBuf,
system_user: String,
source: Error,
},
Utf8String {
path: PathBuf,
context: String,
source: FromUtf8Error,
},
}Expand description
An error that may occur when working with cryptographic types for Signstar.
Variants
ApplyPermissions
An error specific to Signstar config handling. Applying permissions to a file or directory failed.
Fields
Chown
The ownership of a path can not be changed.
Fields
CommandAttachToStdin
Unable to attach to stdin of a command.
CommandBackground
A command exited unsuccessfully.
Fields
CommandExec
A command could not be executed.
CommandNonZero
A command exited unsuccessfully.
Fields
exit_status: ExitStatusThe exit status of command.
CommandWriteToStdin
Unable to write to stdin of a command.
Fields
IoPath
An I/O error occurred at a path.
Fields
NotRunningAsRoot
The current user is an unprivileged user, but should be root.
Fields
RunningAsRoot
The current user is root, but should be an unprivileged user.
Fields
SecretsDirCreate
A passphrase directory can not be created.
Fields
SecretsFileCreate
A secrets file can not be created.
Fields
SecretsFileMetadata
The file metadata of a secrets file cannot be retrieved.
Fields
SecretsFileMissing
A secrets file does not exist.
SecretsFileNotAFile
A secrets file is not a file.
SecretsFilePermissions
A secrets file does not have the correct permissions.
Fields
SecretsFileRead
A secrets file cannot be read.
Fields
SecretsFileWrite
A secrets file can not be written to.
Fields
Utf8String
A UTF-8 error occurred when trying to convert a byte vector to a string.